@@ -1,4 +1,4 @@
-from dynamic_element import DynamicElement
+from .dynamic_element import DynamicElement
 
 console_element = str | DynamicElement
 line_type = str | list[console_element]
\ No newline at end of file
